==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/SeriesVisualDataManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { Base, fromEnum, typeCast, markType, getInstanceType } from "igniteui-angular-core";
import { ISeriesVisualDataManager_$type } from "./ISeriesVisualDataManager";
import { StackedSeriesVisualData } from "./StackedSeriesVisualData";
import { SeriesVisualData } from "./SeriesVisualData";
import { MarkerVisualData } from "./MarkerVisualData";
import { RectData } from "igniteui-angular-core";
import { PrimitiveAppearanceData } from "igniteui-angular-core";
import { DataContext } from "igniteui-angular-core";
import { Color } from "igniteui-angular-core";
import { ColorData } from "igniteui-angular-core";
import { AppearanceHelper } from "igniteui-angular-core";
import { PathVisualData } from "igniteui-angular-core";
import { PolygonVisualData } from "igniteui-angular-core";
import { PolyLineVisualData } from "igniteui-angular-core";
import { RectangleVisualData } from "igniteui-angular-core";
import { PointerTooltipVisualData } from "./PointerTooltipVisualData";
import { CalloutVisualData } from "./CalloutVisualData";
import { LineVisualData } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesVisualDataManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesVisualDataManager, _super);
    function SeriesVisualDataManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesVisualDataManager.prototype.addSubSeriesVisualData = function (a, b) {
        var c = a;
        var d = b;
        c.fragmentSeries.add(d);
    };
    SeriesVisualDataManager.prototype.copyVisualData = function (a, b) {
        var e_1, _a, e_2, _b;
        var c = a;
        var d = b;
        try {
            for (var _c = __values(fromEnum(d.shapes)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var e = _d.value;
                c.shapes.add(e);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        try {
            for (var _e = __values(fromEnum(d.markerShapes)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var f = _f.value;
                c.markerShapes.add(f);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        c.pixels = d.pixels;
        c.pixelWidth = d.pixelWidth;
    };
    SeriesVisualDataManager.prototype.createFragmentVisualData = function (a, b, c, d) {
        var e = new SeriesVisualData();
        e.viewport = RectData.b(b);
        e.type = c;
        e.name = d;
        return e;
    };
    SeriesVisualDataManager.prototype.exportMarkerVisualData = function (a, b) {
        var _this = this;
        var c = b;
        a.qk.cf(function (d) {
            var e = _this.getMarkerVisualData(a, d, a.q6);
            c.markerShapes.add(typeCast(MarkerVisualData.$, e));
        });
    };
    SeriesVisualDataManager.prototype.getMarkerVisualData = function (a, b, c) {
        var d = new MarkerVisualData();
        var e = new PrimitiveAppearanceData();
        d.x = b.n;
        d.y = b.o;
        d.bounds = new RectData(b.n - (b.m / 2), b.o - (b.l / 2), b.m, b.l);
        e.fill = ColorData.a_1(Color.u(0, 0, 0, 0));
        e.stroke = ColorData.a_1(Color.u(0, 0, 0, 0));
        d.index = -1;
        d.contentTemplate = b.ah;
        if (b.content != null && typeCast(DataContext.$, b.content) !== null && b._visibility == 0) {
            var f = b.content;
            e.fill = AppearanceHelper.b(f.actualItemBrush);
            e.fillExtended = AppearanceHelper.a(f.actualItemBrush);
            e.stroke = AppearanceHelper.b(f.outline);
            e.strokeExtended = AppearanceHelper.a(f.outline);
            e.strokeThickness = a.f6();
            if (f.item != null) {
                d.index = a.cl.indexOf(f.item);
            }
        }
        e.isVisible = b._visibility == 0;
        d.isVisible = b._visibility == 0;
        d.markerAppearance = e;
        d.markerType = this.a(a, c);
        return d;
    };
    SeriesVisualDataManager.prototype.a = function (a, b) {
        if (b == a.ce.pm) {
            return "Circle";
        }
        else if (b == a.ce.pn) {
            return "Diamond";
        }
        else if (b == a.ce.po) {
            return "Hexagon";
        }
        else if (b == a.ce.pp) {
            return "Hexagram";
        }
        else if (b == a.ce.pq) {
            return "Pentagon";
        }
        else if (b == a.ce.pr) {
            return "Pentagram";
        }
        else if (b == a.ce.ps) {
            return "Pyramid";
        }
        else if (b == a.ce.pt) {
            return "Square";
        }
        else if (b == a.ce.pu) {
            return "Tetragram";
        }
        else if (b == a.ce.pv) {
            return "Triangle";
        }
        else {
            return "None";
        }
    };
    SeriesVisualDataManager.prototype.exportMarkerVisualDataFromMarker = function (a, b, c) {
        var d = b;
        var e = new MarkerVisualData();
        var f = new PrimitiveAppearanceData();
        e.x = c.n;
        e.y = c.o;
        e.bounds = new RectData(c.n - (c.m / 2), c.o - (c.l / 2), c.m, c.l);
        e.index = -1;
        e.contentTemplate = c.ah;
        if (typeCast(DataContext.$, c.content) !== null) {
            var g = c.content;
            f.fill = AppearanceHelper.b(g.actualItemBrush);
            f.stroke = AppearanceHelper.b(g.outline);
        }
        e.isVisible = c._visibility == 0;
        e.markerAppearance = f;
        if (c.ah == a.ce.pm) {
            e.markerType = "Circle";
        }
        else if (c.ah == a.ce.pn) {
            e.markerType = "Diamond";
        }
        else if (c.ah == a.ce.po) {
            e.markerType = "Hexagon";
        }
        else if (c.ah == a.ce.pp) {
            e.markerType = "Hexagram";
        }
        else if (c.ah == a.ce.pq) {
            e.markerType = "Pentagon";
        }
        else if (c.ah == a.ce.pr) {
            e.markerType = "Pentagram";
        }
        else if (c.ah == a.ce.ps) {
            e.markerType = "Pyramid";
        }
        else if (c.ah == a.ce.pt) {
            e.markerType = "Square";
        }
        else if (c.ah == a.ce.pu) {
            e.markerType = "Tetragram";
        }
        else if (c.ah == a.ce.pv) {
            e.markerType = "Triangle";
        }
        else {
            e.markerType = "None";
        }
        d.markerShapes.add(e);
    };
    SeriesVisualDataManager.prototype.exportPathData = function (a, b, c, d) {
        var e = a;
        var f = new PathVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportPolygonData = function (a, b, c, d) {
        var e = a;
        var f = new PolygonVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportPolylineData = function (a, b, c, d) {
        var e = a;
        var f = new PolyLineVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportRectangleData = function (a, b, c, d) {
        var e = a;
        var f = new RectangleVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportStackedVisualData = function (a, b) {
        var c = new StackedSeriesVisualData();
        c.viewport = RectData.b(b);
        c.type = getInstanceType(a).typeName;
        c.name = a.name;
        return c;
    };
    SeriesVisualDataManager.prototype.exportTrendlineData = function (a, b, c) {
        var d = b;
        var e = new PolyLineVisualData(1, "trendLine", c);
        e.tags.add("Trend");
        d.shapes.add(e);
    };
    SeriesVisualDataManager.prototype.exportVisualData = function (a, b) {
        var c = new SeriesVisualData();
        c.viewport = RectData.b(b);
        c.type = this.b(getInstanceType(a).typeName);
        c.name = a.name;
        c.opacity = a._opacity;
        return c;
    };
    SeriesVisualDataManager.prototype.exportSeriesPixelsData = function (a, b, c, d) {
        var e = a;
        e.pixels = b;
        e.pixelWidth = c;
        e.pixelHeight = d;
    };
    SeriesVisualDataManager.prototype.b = function (a) {
        return a;
    };
    SeriesVisualDataManager.prototype.addPointerTooltipData = function (a, b, c, d, e) {
        if (b == null) {
            return;
        }
        var f = a;
        var g = b;
        g.offsetX = c;
        g.offsetY = d;
        g.categoryNames = e;
        f.pointerTooltips.add(g);
    };
    SeriesVisualDataManager.prototype.addPointerTooltipWithDataLegend = function (a, b, c, d, e) {
        if (b == null) {
            return;
        }
        var f = a;
        var g = b;
        g.offsetX = c;
        g.offsetY = d;
        g.content = e;
        f.pointerTooltips.add(g);
    };
    SeriesVisualDataManager.prototype.exportPointerTooltipData = function (a, b, c, d) {
        var e = new PointerTooltipVisualData();
        e.pointerFillShape = new PolygonVisualData(1, "fillShape", a);
        e.pointerOutlineShape = new PolyLineVisualData(1, "outlineShape", b);
        e.boxShape = new RectangleVisualData(1, "boxShape", c);
        e.viewport = RectData.b(d);
        return e;
    };
    SeriesVisualDataManager.prototype.exportCalloutData = function (a, b, c, d, e, f, g, h, i, j, k) {
        var l = new CalloutVisualData();
        l.left = a;
        l.top = b;
        l.marginLeft = c;
        l.marginTop = d;
        l.background = new RectangleVisualData(1, "calloutBackground", f);
        l.text = AppearanceHelper.c(g, h);
        l.line = new LineVisualData(1, "calloutLeaderLine", i);
        e.calloutShapes.add(l);
    };
    SeriesVisualDataManager.$t = markType(SeriesVisualDataManager, 'SeriesVisualDataManager', Base.$, [ISeriesVisualDataManager_$type]);
    return SeriesVisualDataManager;
}(Base));
export { SeriesVisualDataManager };

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm5/lib/SeriesVisualDataManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { Base, fromEnum, typeCast, markType, getInstanceType } from "igniteui-angular-core";
import { ISeriesVisualDataManager_$type } from "./ISeriesVisualDataManager";
import { StackedSeriesVisualData } from "./StackedSeriesVisualData";
import { SeriesVisualData } from "./SeriesVisualData";
import { MarkerVisualData } from "./MarkerVisualData";
import { RectData } from "igniteui-angular-core";
import { PrimitiveAppearanceData } from "igniteui-angular-core";
import { DataContext } from "igniteui-angular-core";
import { Color } from "igniteui-angular-core";
import { ColorData } from "igniteui-angular-core";
import { AppearanceHelper } from "igniteui-angular-core";
import { PathVisualData } from "igniteui-angular-core";
import { PolygonVisualData } from "igniteui-angular-core";
import { PolyLineVisualData } from "igniteui-angular-core";
import { RectangleVisualData } from "igniteui-angular-core";
import { PointerTooltipVisualData } from "./PointerTooltipVisualData";
import { CalloutVisualData } from "./CalloutVisualData";
import { LineVisualData } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesVisualDataManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesVisualDataManager, _super);
    function SeriesVisualDataManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesVisualDataManager.prototype.addSubSeriesVisualData = function (a, b) {
        var c = a;
        var d = b;
        c.fragmentSeries.add(d);
    };
    SeriesVisualDataManager.prototype.copyVisualData = function (a, b) {
        var e_1, _a, e_2, _b;
        var c = a;
        var d = b;
        try {
            for (var _c = __values(fromEnum(d.shapes)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var e = _d.value;
                c.shapes.add(e);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        try {
            for (var _e = __values(fromEnum(d.markerShapes)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var f = _f.value;
                c.markerShapes.add(f);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        c.pixels = d.pixels;
        c.pixelWidth = d.pixelWidth;
    };
    SeriesVisualDataManager.prototype.createFragmentVisualData = function (a, b, c, d) {
        var e = new SeriesVisualData();
        e.viewport = RectData.b(b);
        e.type = c;
        e.name = d;
        return e;
    };
    SeriesVisualDataManager.prototype.exportMarkerVisualData = function (a, b) {
        var _this = this;
        var c = b;
        a.qk.cf(function (d) {
            var e = _this.getMarkerVisualData(a, d, a.q6);
            c.markerShapes.add(typeCast(MarkerVisualData.$, e));
        });
    };
    SeriesVisualDataManager.prototype.getMarkerVisualData = function (a, b, c) {
        var d = new MarkerVisualData();
        var e = new PrimitiveAppearanceData();
        d.x = b.n;
        d.y = b.o;
        d.bounds = new RectData(b.n - (b.m / 2), b.o - (b.l / 2), b.m, b.l);
        e.fill = ColorData.a_1(Color.u(0, 0, 0, 0));
        e.stroke = ColorData.a_1(Color.u(0, 0, 0, 0));
        d.index = -1;
        d.contentTemplate = b.ah;
        if (b.content != null && typeCast(DataContext.$, b.content) !== null && b._visibility == 0) {
            var f = b.content;
            e.fill = AppearanceHelper.b(f.actualItemBrush);
            e.fillExtended = AppearanceHelper.a(f.actualItemBrush);
            e.stroke = AppearanceHelper.b(f.outline);
            e.strokeExtended = AppearanceHelper.a(f.outline);
            e.strokeThickness = a.f6();
            if (f.item != null) {
                d.index = a.cl.indexOf(f.item);
            }
        }
        e.isVisible = b._visibility == 0;
        d.isVisible = b._visibility == 0;
        d.markerAppearance = e;
        d.markerType = this.a(a, c);
        return d;
    };
    SeriesVisualDataManager.prototype.a = function (a, b) {
        if (b == a.ce.pv) {
            return "Circle";
        }
        else if (b == a.ce.pw) {
            return "Diamond";
        }
        else if (b == a.ce.px) {
            return "Hexagon";
        }
        else if (b == a.ce.py) {
            return "Hexagram";
        }
        else if (b == a.ce.pz) {
            return "Pentagon";
        }
        else if (b == a.ce.p0) {
            return "Pentagram";
        }
        else if (b == a.ce.p1) {
            return "Pyramid";
        }
        else if (b == a.ce.p2) {
            return "Square";
        }
        else if (b == a.ce.p3) {
            return "Tetragram";
        }
        else if (b == a.ce.p4) {
            return "Triangle";
        }
        else {
            return "None";
        }
    };
    SeriesVisualDataManager.prototype.exportMarkerVisualDataFromMarker = function (a, b, c) {
        var d = b;
        var e = new MarkerVisualData();
        var f = new PrimitiveAppearanceData();
        e.x = c.n;
        e.y = c.o;
        e.bounds = new RectData(c.n - (c.m / 2), c.o - (c.l / 2), c.m, c.l);
        e.index = -1;
        e.contentTemplate = c.ah;
        if (typeCast(DataContext.$, c.content) !== null) {
            var g = c.content;
            f.fill = AppearanceHelper.b(g.actualItemBrush);
            f.stroke = AppearanceHelper.b(g.outline);
        }
        e.isVisible = c._visibility == 0;
        e.markerAppearance = f;
        if (c.ah == a.ce.pv) {
            e.markerType = "Circle";
        }
        else if (c.ah == a.ce.pw) {
            e.markerType = "Diamond";
        }
        else if (c.ah == a.ce.px) {
            e.markerType = "Hexagon";
        }
        else if (c.ah == a.ce.py) {
            e.markerType = "Hexagram";
        }
        else if (c.ah == a.ce.pz) {
            e.markerType = "Pentagon";
        }
        else if (c.ah == a.ce.p0) {
            e.markerType = "Pentagram";
        }
        else if (c.ah == a.ce.p1) {
            e.markerType = "Pyramid";
        }
        else if (c.ah == a.ce.p2) {
            e.markerType = "Square";
        }
        else if (c.ah == a.ce.p3) {
            e.markerType = "Tetragram";
        }
        else if (c.ah == a.ce.p4) {
            e.markerType = "Triangle";
        }
        else {
            e.markerType = "None";
        }
        d.markerShapes.add(e);
    };
    SeriesVisualDataManager.prototype.exportPathData = function (a, b, c, d) {
        var e = a;
        var f = new PathVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportPolygonData = function (a, b, c, d) {
        var e = a;
        var f = new PolygonVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportPolylineData = function (a, b, c, d) {
        var e = a;
        var f = new PolyLineVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportRectangleData = function (a, b, c, d) {
        var e = a;
        var f = new RectangleVisualData(1, c, b);
        if (d != null) {
            for (var g = 0; g < d.length; g++) {
                f.tags.add(d[g]);
            }
        }
        e.shapes.add(f);
    };
    SeriesVisualDataManager.prototype.exportStackedVisualData = function (a, b) {
        var c = new StackedSeriesVisualData();
        c.viewport = RectData.b(b);
        c.type = getInstanceType(a).typeName;
        c.name = a.name;
        return c;
    };
    SeriesVisualDataManager.prototype.exportTrendlineData = function (a, b, c) {
        var d = b;
        var e = new PolyLineVisualData(1, "trendLine", c);
        e.tags.add("Trend");
        d.shapes.add(e);
    };
    SeriesVisualDataManager.prototype.exportVisualData = function (a, b) {
        var c = new SeriesVisualData();
        c.viewport = RectData.b(b);
        c.type = this.b(getInstanceType(a).typeName);
        c.name = a.name;
        c.opacity = a._opacity;
        return c;
    };
    SeriesVisualDataManager.prototype.exportSeriesPixelsData = function (a, b, c, d) {
        var e = a;
        e.pixels = b;
        e.pixelWidth = c;
        e.pixelHeight = d;
    };
    SeriesVisualDataManager.prototype.b = function (a) {
        return a;
    };
    SeriesVisualDataManager.prototype.addPointerTooltipData = function (a, b, c, d, e) {
        if (b == null) {
            return;
        }
        var f = a;
        var g = b;
        g.offsetX = c;
        g.offsetY = d;
        g.categoryNames = e;
        f.pointerTooltips.add(g);
    };
    SeriesVisualDataManager.prototype.addPointerTooltipWithDataLegend = function (a, b, c, d, e) {
        if (b == null) {
            return;
        }
        var f = a;
        var g = b;
        g.offsetX = c;
        g.offsetY = d;
        g.content = e;
        f.pointerTooltips.add(g);
    };
    SeriesVisualDataManager.prototype.exportPointerTooltipData = function (a, b, c, d) {
        var e = new PointerTooltipVisualData();
        e.pointerFillShape = new PolygonVisualData(1, "fillShape", a);
        e.pointerOutlineShape = new PolyLineVisualData(1, "outlineShape", b);
        e.boxShape = new RectangleVisualData(1, "boxShape", c);
        e.viewport = RectData.b(d);
        return e;
    };
    SeriesVisualDataManager.prototype.exportCalloutData = function (a, b, c, d, e, f, g, h, i, j, k) {
        var l = new CalloutVisualData();
        l.left = a;
        l.top = b;
        l.marginLeft = c;
        l.marginTop = d;
        l.background = new RectangleVisualData(1, "calloutBackground", f);
        l.text = AppearanceHelper.c(g, h);
        l.line = new LineVisualData(1, "calloutLeaderLine", i);
        e.calloutShapes.add(l);
    };
    SeriesVisualDataManager.$t = markType(SeriesVisualDataManager, 'SeriesVisualDataManager', Base.$, [ISeriesVisualDataManager_$type]);
    return SeriesVisualDataManager;
}(Base));
export { SeriesVisualDataManager };
